@@ -1,5 +1,4 @@
 #!/bin/env python
-# (C) Copyright 2015 Hewlett Packard Enterprise Development Company LP
 """Monitoring Agent remote host aliveness checker.
 
 """
@@ -9,7 +8,6 @@ import subprocess
 import sys
 
 import monasca_agent.collector.checks.services_checks as services_checks
-import monasca_agent.common.util as util
 
 
 class HostAlive(services_checks.ServicesCheck):
@@ -74,16 +72,19 @@ class HostAlive(services_checks.ServicesCheck):
         ping_command = ping_prefix + host
 
         try:
-            subprocess.check_output(ping_command.split(" "), stderr=subprocess.STDOUT)
+            ping = subprocess.check_output(ping_command.split(" "), stderr=subprocess.STDOUT)
         except subprocess.CalledProcessError:
-            error_message = 'Host not accessible, ping test failed ("{0}")'.format(ping_command)
-            self.log.info(error_message)
-            return False, error_message
-        except OSError as err:
-            error_message = 'ping command "{0}" failed to run: {1}'.format(ping_command, err)
+            error_message = 'ping command "{0}" failed to execute on operating system'.format(ping_command)
             self.log.warn(error_message)
             return False, error_message
-        return True, None
+
+        # Look at the output for a packet loss percentage
+        if (ping.find('100%') > 0) or (ping.find('100.0%') > 0):
+            error_message = 'ping command "{0}" failed. {1} is not available.'.format(ping_command, host)
+            self.log.warn(error_message)
+            return False, error_message
+        else:
+            return True, None
 
     def _create_status_event(self, status, msg, instance):
         """Does nothing: status events are not yet supported by Mon API.
@@ -99,8 +100,8 @@ class HostAlive(services_checks.ServicesCheck):
         if not instance['host_name']:
             raise ValueError('Target hostname not specified!')
 
-        dimensions = self._set_dimensions({'hostname': instance['host_name'],
-                                           'observer_host': util.get_hostname()},
+        dimensions = self._set_dimensions({'target_host': instance['host_name'],
+                                           'observer_host': socket.getfqdn()},
                                           instance)
 
         success = False
@@ -127,4 +128,6 @@ class HostAlive(services_checks.ServicesCheck):
                        1,
                        dimensions=dimensions,
                        value_meta={'error': error_message})
+            self.log.error('Host alive check for {0} failed.  Error was {1}'.format(instance['host_name'],
+                                                                                    error_message))
             return services_checks.Status.DOWN, "DOWN"
