@@ -20,6 +20,7 @@ import uuid
 import logging
 log = logging.getLogger(__name__)
 
+
 # Tornado
 try:
     from tornado import ioloop, version_info as tornado_version
@@ -384,7 +385,6 @@ class Paths(object):
         log.info("Windows certificate path: %s" % crt_path)
         tornado.simple_httpclient._DEFAULT_CA_CERTS = crt_path
 
-
 def plural(count):
     if count == 1:
         return ""
@@ -494,7 +494,7 @@ def get_hostname():
 
     Tries, in order:
 
-      * agent config (agent.conf, "hostname:")
+      * agent config (agent.yaml, "hostname:")
       * 'hostname -f' (on unix)
       * socket.gethostname()
     """
@@ -536,9 +536,9 @@ def get_hostname():
 
     if hostname is None:
         log.critical(
-            'Unable to reliably determine host name. You can define one in agent.conf or in your hosts file')
+            'Unable to reliably determine host name. You can define one in agent.yaml or in your hosts file')
         raise Exception(
-            'Unable to reliably determine host name. You can define one in agent.conf or in your hosts file')
+            'Unable to reliably determine host name. You can define one in agent.yaml or in your hosts file')
     else:
         return hostname
 
